@@ -53,7 +53,7 @@ def launch_ui(opyrator_path: str, port: int = 8501) -> None:
             python_path = f"set PYTHONPATH=%PYTHONPATH%;{getcwd()} &&"
 
         subprocess.run(
-            f"{python_path} {sys.executable} -m streamlit run --server.port={port} --server.headless=True --runner.magicEnabled=False --server.maxUploadSize=50 --browser.gatherUsageStats=False {f.name}",
+            f"""{python_path} "{sys.executable}" -m streamlit run --server.port={port} --server.headless=True --runner.magicEnabled=False --server.maxUploadSize=50 --browser.gatherUsageStats=False {f.name}""",
             shell=True,
         )
 
@@ -826,8 +826,6 @@ def render_streamlit_ui(opyrator: Opyrator) -> None:
     session_state = streamlit_utils.get_session_state()
 
     title = opyrator.name
-    if "opyrator" not in opyrator.name.lower():
-        title += " - Opyrator"
 
     # Page config can only be setup once
     # st.set_page_config(page_title="Opyrator", page_icon=":arrow_forward:")
